@@ -232,7 +232,8 @@ function submitbutton(pressbutton)
 				<div class="input-wrap">
 					<label><?php echo Lang::txt('COM_PROJECTS_PRIVACY'); ?>:</label>
 					<select name="private">
-						<option value="0" <?php if ($this->model->isPublic()) { echo ' selected="selected"'; } ?>><?php echo Lang::txt('COM_PROJECTS_PUBLIC'); ?></option>
+						<option value="-1" <?php if ($this->model->get('private') < 0) { echo ' selected="selected"'; } ?>><?php echo Lang::txt('COM_PROJECTS_OPEN'); ?></option>
+						<option value="0" <?php if ($this->model->get('private') == 0) { echo ' selected="selected"'; } ?>><?php echo Lang::txt('COM_PROJECTS_PUBLIC'); ?></option>
 						<option value="1" <?php if (!$this->model->isPublic()) { echo ' selected="selected"'; } ?>><?php echo Lang::txt('COM_PROJECTS_PRIVATE'); ?></option>
 					</select>
 				</div>
@@ -287,7 +288,10 @@ function submitbutton(pressbutton)
 					</div>
 					<div class="input-wrap">
 						<label><?php echo Lang::txt('COM_PROJECTS_TERMS_GRANT_APPROVAL_CODE'); ?>:</label>
-						<?php $approval = $this->escape(html_entity_decode($this->params->get( 'grant_approval'))); echo $approval ? $approval : Lang::txt('COM_PROJECTS_NA'); ?>
+						<?php 
+						$approval = $this->escape(html_entity_decode($this->params->get( 'grant_approval')));
+						echo $approval ? $approval : Lang::txt('COM_PROJECTS_NA');
+						?>
 					</div>
 				<?php } ?>
 			</fieldset>
@@ -296,6 +300,11 @@ function submitbutton(pressbutton)
 				<fieldset class="adminform">
 					<legend><?php echo Lang::txt('COM_PROJECTS_FILES'); ?></legend>
 
+					<div class="input-wrap">
+						<input name="params[versionTracking]" type="hidden" value="0" />
+						<input name="params[versionTracking]" type="checkbox" value="1" <?php echo ($this->params->get('versionTracking', '1') == '1') ? 'checked="checked"' : '';?> class="option" ><label><?php echo Lang::txt('Version Tracking'); ?> </label></input>
+					</div>
+
 					<div class="input-wrap">
 						<label><?php echo Lang::txt('Files Quota'); ?>: <?php echo ' (' . Lang::txt('COM_PROJECTS_FILES_GBYTES').')'; ?></label>
 						<input name="params[quota]" maxlength="100" type="text" value="<?php echo \Components\Projects\Helpers\Html::convertSize($quota, 'b', 'GB', 2); ?>" class="short" />
